@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 14's 2.6.35 kernel.
+# This is a kernel build script for Fedora 13's 2.6.34 kernel.
 #
 
 die () {
@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.35.10-74.fc14.src.rpm ]
+if [ ! -r kernel-2.6.34.8-68.fc13.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/14/SRPMS/kernel-2.6.35.10-74.fc14.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/13/SRPMS/kernel-2.6.34.8-68.fc13.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.35.10-74.fc14.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.35.10-74.fc14.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.34.8-68.fc13.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.34.8-68.fc13.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.2-20110121.tar.gz ]
+if [ ! -r ccs-patch-1.7.3-20110401.tar.gz ]
 then
-    wget -O ccs-patch-1.7.2-20110121.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20110121.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.7.3-20110401.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.3-20110401.tar.gz' || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
@@ -33,11 +33,11 @@ patch << "EOF" || die "Can't patch spec file."
  # (Uncomment the '#' and both spaces below to set the buildid.)
  #
 -# % define buildid .local
-+%define buildid _tomoyo_1.7.2p4
++%define buildid _tomoyo_1.7.3
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
-@@ -412,6 +412,11 @@
+@@ -409,6 +409,11 @@
  # to versions below the minimum
  #
  
@@ -58,27 +58,27 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -900,7 +905,7 @@
+@@ -992,7 +997,7 @@
+ Provides: kernel-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
- Requires: perl\
 -%description -n kernel%{?variant}%{?1:-%{1}}-devel\
 +%description -n ccs-kernel%{?variant}%{?1:-%{1}}-devel\
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1498,6 +1503,10 @@
+@@ -1694,6 +1699,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.2-20110121.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.35-fedora-14.diff
++tar -zxf %_sourcedir/ccs-patch-1.7.3-20110401.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.34-fedora-13.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1526,6 +1535,9 @@
+@@ -1722,6 +1731,9 @@
  for i in *.config
  do
    mv $i .config
@@ -101,7 +101,7 @@ sleep 30
 patch << "EOF" || die "Can't patch spec file."
 --- /root/rpmbuild/SPECS/ccs-kernel.spec
 +++ /root/rpmbuild/SPECS/ccs-kernel.spec
-@@ -220,7 +220,7 @@
+@@ -221,7 +221,7 @@
  
  # kernel-PAE is only built on i686.
  %ifarch i686
